# AlpacaPy


### Dev setup

This project is managed via poetry so setup should be just running `poetry install`.

This repo is using [`pre-commit`](https://pre-commit.com/) to setup some checks to happen at commit time
to keep the repo clean. To set these up after you've run `poetry install` just run `poetry run pre-commit
install` to have pre-commit setup these hooks
